<div align="center">
    <img src="../../docs/images/logo-title.png" height="80px">
    <h3>The Graph Of LIfe Library.</h3>
</div>


## What is in this folder? 

- `_load.py` and `config_convert.py`: loading from `yaml` config file 
- `_loader.py`: retrieve relevant arguments from the config and loading different modules with the correct arguments